@@ -102,7 +102,7 @@ use overload
     my $x1 = shift;
     my $r = $x1->r;
     
-    return Rstats::Func::negation($r, $x1, @_);
+    return Rstats::Func::negate($r, $x1, @_);
   },
   '""' => sub {
     my $x1 = shift;
